@@ -7,8 +7,13 @@
 #ifndef _EPGSYNC_I18N__H
 #define _EPGSYNC_I18N__H
 
+#include <vdr/config.h>
 #include <vdr/i18n.h>
 
+#if VDRVERSNUM < 10507
+#define trNOOP(s) (s)
+#define trVDR(s) tr(s)
 extern const tI18nPhrase Phrases[];
+#endif
 
 #endif //_EPGSYNC_I18N__H
